@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # shortcuts
 use constant os_freebsd  => (os => 'freebsd');
@@ -207,7 +207,11 @@ sub mapping {
 	[package => 'libdb4.8-dev']],
        [linuxdistrocodename => 'wheezy',
 	[package => 'libdb5.1-dev']],
-       [package => 'libdb5.3-dev']]],
+       [package => 'libdb5.3-dev']],
+      [os_darwin,
+       # Make sure that a corresponding distroprefs file matches this library (see srezic-cpan-distroprefs).
+       [package => 'berkeley-db']],
+     ],
 
      [cpanmod => 'Bio::HTS',
       [os_freebsd,
@@ -413,7 +417,10 @@ sub mapping {
      [cpanmod => 'DBD::mysql',
       # XXX freebad?
       [like_debian,
-       [package => 'libmysqlclient-dev']]],
+       [package => 'libmysqlclient-dev']],
+      [os_darwin,
+       [package => 'mysql-connector-c | mysql']],
+     ],
 
      [cpanmod => 'DBD::ODBC',
       [os_freebsd,
@@ -487,9 +494,11 @@ sub mapping {
        [package => 'g++']]],
 
      [cpanmod => 'ExtUtils::F77',
-      # XXX FreeBSD?
+      # XXX TBD FreeBSD: provided by gcc, which is in the base system for osvers < 10, and has to be installed separately for osvers >= 10
       [like_debian,
-       [package => 'gfortran']]],
+       [package => 'gfortran']],
+      # XXX TBD MacOSX: "GNU Fortran is now provided as part of GCC, and can be installed with: brew install gcc"
+     ],
 
      [cpanmod => 'ExtUtils::PkgConfig',
       [os_freebsd,
@@ -540,7 +549,7 @@ sub mapping {
 
      [cpanmod => 'GD',
       [os_freebsd,
-       [package => 'gd']],
+       [package => 'libgd']],
       [like_debian,
        [linuxdistrocodename => ['precise', 'wheezy'],
 	[package => 'libgd2-noxpm-dev | libgd2-xpm-dev']],
@@ -562,7 +571,7 @@ sub mapping {
       [os_freebsd,
        [package => 'libproj4']],
       [like_debian,
-       [package => 'libproj-dev']],
+       [package => ['libproj-dev', 'proj-bin']]],
       [os_darwin,
        [package => 'proj']],
      ],
@@ -657,7 +666,7 @@ sub mapping {
       [like_debian,
        [package => 'libprotoc-dev']]],
 
-     [cpanmod => 'Graphics::GnuplotIF',
+     [cpanmod => ['Graphics::GnuplotIF', 'Gnuplot::Simple'],
       [package => 'gnuplot']],
 
      [cpanmod => 'Graphics::Plotter',
@@ -672,7 +681,7 @@ sub mapping {
       [like_debian,
        [package => 'libsane-dev']]],
 
-     [cpanmod => ['GraphViz', 'GraphViz2::Marpa'],
+     [cpanmod => ['GraphViz', 'GraphViz2', 'GraphViz2::Marpa'],
       # package named the same in freebsd, debian and macosx/homebrew, maybe everywhere?
       [package => 'graphviz']],
 
@@ -693,6 +702,13 @@ sub mapping {
       [like_debian,
        [package => 'libgtk-3-dev']]],
 
+     [cpanmod => 'Gtk3::WebKit',
+      [os_freebsd,
+       [package => 'webkit-gtk3']],
+      [like_debian,
+       [package => 'libwebkitgtk-3.0-dev']],
+     ],
+
      [cpanmod => 'GTop',
       [os_freebsd,
        [package => 'libgtop']],
@@ -1212,7 +1228,8 @@ sub mapping {
       ]],
 
      [cpanmod => 'PGPLOT',
-      # XXX freebsd?
+      [os_freebsd,
+       [package => 'pgplot']],
       [like_debian,
        [package => 'pgplot5']]],
 
@@ -1456,6 +1473,11 @@ sub mapping {
       [like_debian,
        [package => ['mesa-common-dev', 'libglu1-mesa-dev']]]],
 
+     [cpanmod => ['UAV::Pilot::SDL', 'UAV::Pilot::Video::Ffmpeg'],
+      [like_debian,
+       [package => 'libavcodec-dev']],
+     ],
+
      [cpanmod => 'UDT::Simple',
       [os_freebsd,
        [package => 'udt']],
